Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1385)

Unified Diff: bin/function_size_analysis.dart

Issue 1412903002: include fields in verify_deps, refactor graph dfs (Closed) Base URL: git@github.com:dart-lang/dart2js_info.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | bin/verify_deps.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: bin/function_size_analysis.dart
diff --git a/bin/function_size_analysis.dart b/bin/function_size_analysis.dart
index 0de3db42e74f87405bb8fe07fbc4a30e00997a60..3606310c1102e09708e72ee8dc75c07ff1e89053 100644
--- a/bin/function_size_analysis.dart
+++ b/bin/function_size_analysis.dart
@@ -31,10 +31,10 @@ showCodeDistribution(AllInfo info,
// Compute a graph from the dependencies in [info].
Graph<Info> graph = graphFromInfo(info);
// Compute the strongest connected components and calculate their size.
var components = graph.computeTopologicalSort();
print('total elements: ${graph.nodes.length}');
- print('total strongest connected components: ${components.length}');
+ print('total strongly connected components: ${components.length}');
var maxS = 0;
var totalCount = graph.nodeCount;
var minS = totalCount;
@@ -31,10 +31,10 @@ showCodeDistribution(AllInfo info,
// Compute a graph from the dependencies in [info].
Graph<Info> graph = graphFromInfo(info);
- // Compute the strongest connected components and calculate their size.
+ // Compute the strongly connected components and calculate their size.
var components = graph.computeTopologicalSort();
print('total elements: ${graph.nodes.length}');
« no previous file with comments | « no previous file | bin/verify_deps.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698